@@ -8,7 +8,14 @@ class LogService:
     def __init__(self):
         self.logger = logging.getLogger(os.getenv('LOGSTASH_NAME'))
         self.logger.setLevel(int(os.getenv('LOGSTASH_LEVEL')))
-        self.logger.addHandler(logstash.TCPLogstashHandler(os.getenv('LOGSTASH_HOST'), os.getenv('LOGSTASH_PORT'), version=1))
+
+        use_logtash = os.getenv('USE_LOGSTASH')
+
+        if use_logtash == 'True':
+            if (self.logger.hasHandlers()):
+                self.logger.handlers.clear()
+            
+            self.logger.addHandler(logstash.TCPLogstashHandler(os.getenv('LOGSTASH_HOST'), os.getenv('LOGSTASH_PORT'), version=1))
 
     def i(self, msg, *args):
         self.logger.info(msg)
